package v1

import (
	"github.com/gin-gonic/gin"
)

import (
	"auth-server/common"
	"auth-server/service"
)

func Ping(c *gin.Context) {
	common.HttpSuccess(c, "pong")
}

func SoftwareInfo(c *gin.Context) {
	rssi := service.ResourceService.GetSoftwareInfo()
	sssi := service.StudyService.GetSoftwareInfo()
	pssi := service.ProtocolService.GetSoftwareInfo()
	dssi := service.DcmtkService.GetSoftwareInfo()
	common.HttpSuccess(c, map[string]interface{}{
		"server": map[string]interface{}{
			"auth-server": map[string]interface{}{
				"desc":    common.Desc,
				"build":   common.Build,
				"version": common.Version,
			},
			"resource-server": map[string]interface{}{
				"desc":    rssi.GetDesc(),
				"build":   rssi.GetBuild(),
				"version": rssi.GetVersion(),
			},
			"study-server": map[string]interface{}{
				"desc":    sssi.GetDesc(),
				"build":   sssi.GetBuild(),
				"version": sssi.GetVersion(),
			},
			"protocol-server": map[string]interface{}{
				"desc":    pssi.GetDesc(),
				"build":   pssi.GetBuild(),
				"version": pssi.GetVersion(),
			},
			"dcmtk-server": map[string]interface{}{
				"desc":    dssi.GetDesc(),
				"build":   dssi.GetBuild(),
				"version": dssi.GetVersion(),
			},
		},
		"language": common.MetadataConfig.GetLanguages(),
		"product":  common.MetadataConfig.GetProduct(),
	})
}

func Login(c *gin.Context) {
	request := &struct {
		Username string `json:"username" binding:"required"`
		Password string `json:"password" binding:"required"`
	}{}
	if err := c.ShouldBindJSON(request); err != nil {
		common.HttpErr(c, err)
		return
	}
	res, err := service.Login(request.Username, request.Password)
	if err != nil {
		common.HttpErr(c, err)
		return
	}
	common.HttpSuccess(c, res)
}
